[//]: # "NOTE: THIS FILE WAS AUTOGENERATED FROM README.md"

# GitHub Actions

Create a file named `.github/workflows/black.yml` inside your repository with:

```yaml
name: Lint

on: [push, pull_request]

jobs:
  lint:
    runs-on: ubuntu-latest
    steps:
      - uses: actions/checkout@v2
      - uses: actions/setup-python@v2
      - uses: psf/black@stable # the default is equivalent to `black . --diff --check`.
        with: # (optional - override the default parameters).
          args: ". --diff --check"
```
